<?php
/**
 * @package   admintools
 * @copyright Copyright (c)2010-2021 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') || die();

/** @var  \Akeeba\Component\AdminTools\Administrator\View\Controlpanel\HtmlView $this */

use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

// IP Workarounds are available on Pro version only
if (!defined('ADMINTOOLS_PRO') || !ADMINTOOLS_PRO)
{
	return;
}

// Let's check if we have to display the notice about IP Workarounds
$display = false;
// Prevent notices if we don't have any incoming return url
$returnurl = $returnurl ?? '';

/** @var \Akeeba\Component\AdminTools\Administrator\Model\ControlpanelModel $controlPanelModel */
$controlPanelModel = $this->getModel('Controlpanel');
$privateNetworks   = $controlPanelModel->needsIpWorkaroundsForPrivNetwork();
$proxyHeader       = $controlPanelModel->needsIpWorkaroundsHeaders();
$display           = ($privateNetworks || $proxyHeader);

// No notices detected, let's stop here
if (!$display)
{
	return;
}

?>
<div class="alert alert-danger">
	<?php if($privateNetworks): ?>
		<p><?=Text::_('COM_ADMINTOOLS_CONTROLPANEL_ERR_PRIVNET_IPS'); ?></p>
	<?php endif; ?>

	<?php if($proxyHeader): ?>
		<p><?=Text::_('COM_ADMINTOOLS_CONTROLPANEL_ERR_PROXY_HEADER'); ?></p>
	<?php endif; ?>

	<p>
		<a href="<?= Route::_('index.php?option=com_admintools&view=Controlpanel&task=IpWorkarounds&enable=1&returnurl=' . $returnurl) ?>"
		   class="btn btn-success">
			<span class="fa fa-check"></span>
			<?= Text::_('COM_ADMINTOOLS_CONTROLPANEL_ERR_PRIVNET_ENABLE') ?>
		</a>
		<a href="<?= Route::_('index.php?option=com_admintools&view=Controlpanel&task=IpWorkarounds&enable=0&returnurl=' . $returnurl) ?>"
		   class="btn btn-outline-danger">
			<span class="fa fa-eye-slash"></span>
			<?=Text::_('COM_ADMINTOOLS_CONTROLPANEL_ERR_PRIVNET_IGNORE'); ?>
		</a>
	</p>
</div>
